Package: MLmetrics
Type: Package
Title: Machine Learning Evaluation Metrics
Version: 1.1.3
Authors@R: person("Yachen", "Yan", email = "yanyachen21@gmail.com", role = c("aut", "cre"))
Description: A collection of evaluation metrics, including loss, score and
    utility functions, that measure regression, classification and ranking performance.
URL: https://github.com/yanyachen/MLmetrics
BugReports: https://github.com/yanyachen/MLmetrics/issues
Depends: R (>= 2.10)
Imports: stats, utils, ROCR
Suggests: e1071
License: GPL-2
RoxygenNote: 5.0.1
NeedsCompilation: no
Packaged: 2024-04-01 02:06:00 UTC; Administrator
Author: Yachen Yan [aut, cre]
Maintainer: Yachen Yan <yanyachen21@gmail.com>
Repository: CRAN
Date/Publication: 2024-04-13 23:50:05 UTC
Built: R 4.6.0; ; 2026-04-26 02:31:33 UTC; unix
