# Generated by roxygen2: do not edit by hand

export(AUC)
export(Accuracy)
export(Area_Under_Curve)
export(ConfusionDF)
export(ConfusionMatrix)
export(F1_Score)
export(FBeta_Score)
export(GainAUC)
export(Gini)
export(KS_Stat)
export(LiftAUC)
export(LogLoss)
export(MAE)
export(MAPE)
export(MSE)
export(MedianAE)
export(MedianAPE)
export(MultiLogLoss)
export(NormalizedGini)
export(PRAUC)
export(Poisson_LogLoss)
export(Precision)
export(R2_Score)
export(RAE)
export(RMSE)
export(RMSLE)
export(RMSPE)
export(RRSE)
export(Recall)
export(Sensitivity)
export(Specificity)
export(ZeroOneLoss)
importFrom(stats,integrate)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,splinefun)
