#' MLmetrics: Machine Learning Evaluation Metrics
#'
#' A collection of evaluation metrics, including loss, score and utility functions, 
#' that measure regression and classification performance.
#'
#' @docType package
#' @name MLmetrics
NULL